/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2012 University of Bonn. All rights reserved.
 * 
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * KeyValueValidator.cpp
 *
 *  Created on: May 14, 2012
 *      Author: ankele
 */


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "KeyValueValidator.hpp"

bool KeyValueValidator::isValid(const KeyValuePair & _value) const
{
  size_t keyvaluestart = 0;
  size_t keyvalueend = _value.length()-1;
  do {
    size_t keyvaluemid = _value.find("=", keyvaluestart);
    if (keyvaluemid == std::string::npos)
      // No "=" found.
      return false;

    if (keyvaluemid == keyvaluestart)
      // Nothing before "=".
      return false;

    if (keyvaluemid == keyvalueend)
      // Nothing after "=".
      return false;

    keyvalueend = keyvaluestart;
    keyvaluestart = _value.find(";", keyvaluestart+1);
    // allow ending semicolon
    if (keyvaluestart == _value.length()-1)
      keyvaluestart = std::string::npos;
  } while (keyvaluestart != std::string::npos);

  return true;
}

bool KeyValueValidator::operator==(const Validator<KeyValuePair> &_instance) const
{
  const KeyValueValidator *inst =
      dynamic_cast<const KeyValueValidator *>(&_instance);
  if (inst)
    return true;
  else
    return false;
}

Validator< KeyValuePair >* KeyValueValidator::clone() const
{
  Validator< KeyValuePair > *inst =
      new KeyValueValidator();
  return inst;
}




